![PyPI](https://img.shields.io/pypi/v/pyheavydb?style=for-the-badge)

## pyheavydb

A python [DB API](https://www.python.org/dev/peps/pep-0249/) compliant
interface for [HeavyDB](https://www.heavy.ai/) (formerly OmniSci and MapD).

